<?php

/********************************************
* My Links Manager 2.0.4
* Copyright (c) 2011-2015 Alexander Yanitsky
* Website: http://janicky.com
* E-mail: janickiy@mail.ru
* Skype: janickiy
********************************************/

ob_start();

// config
require_once '../config/config.inc';

// check install
require_once "../lib/check_install.inc";

// Require necessary classes
require_once '../class/html_template/SeparateTemplate.php';
require_once "../class/class.exception_mysql.php";

try
{
	// Require necessary libs
	require_once "../lib/function.inc";
	require_once "../lib/connect.inc";
		
	// Get a settings of catalogue
	$query = "SELECT * FROM ".DB_SETTING."";
	$result = $dbh->query($query);

	if(!$result) throw new ExceptionMySQL($dbh->error,$query,"Error executing SQL query!");

	$settings = $result->fetch_array();

	$result->close();

	// include template
	include "templates/language/".$settings['language'].".inc";	

	// Authenticate
	require "../lib/authenticate.inc";

	$error = Array();

	if(!empty($_POST["action"])){
		$_POST["name"] = stripslashes(htmlspecialchars(trim($_POST["name"])));
		$_POST['url'] = strtolower(trim($_POST['url']));
		$_POST['reciprocal_link'] =  strtolower(trim($_POST['reciprocal_link']));
		$_POST["email"] = strtolower(trim($_POST["email"]));
		$_POST["description"] = stripslashes(htmlspecialchars(trim($_POST["description"])));
		$_POST["full_description"] = stripslashes(htmlspecialchars(trim($_POST["full_description"])));
		$_POST["keywords"] = htmlspecialchars(trim($_POST["keywords"]));
		$_POST["htmlcode_banner"] = stripslashes(trim($_POST["htmlcode_banner"]));

		$check_link = $_POST['check_link'] == 'on'? 'yes':'no';

		// Cut out http:// from url of site
		if(!empty($_POST["url"])){
			if(substr($_POST["url"], 0, 7) == "http://") $_POST["url"] = str_replace('http://','',$_POST["url"]);
			if(strpos($_POST["url"],'/') > 0) list($_POST["url"]) = explode('/',$_POST["url"]);
		}

		// Cut out http:// from url address of reciprocal link
		if(!empty($_POST["reciprocal_link"])){
			if(substr(strtolower($_POST["reciprocal_link"]), 0, 7) == "http://") $_POST["reciprocal_link"] = str_replace('http://','',$_POST["reciprocal_link"]);
		}

		// Cut out all unnecessary tags and javascripts from HTML code of banner
		$_POST["htmlcode_banner"] = cuttags($_POST["htmlcode_banner"]);

		// Check catalogue already has adding link, if it has then print error
		if(!empty($_POST["url"])){
			$src_url = $_POST["url"];

			if(substr($_POST["url"], 0, 4) == "www.") $src_url = str_replace('www.','',$src_url); 
			$src_url = str_replace('.','\\.',$src_url);

			$query = "SELECT * FROM ".DB_LINKS." WHERE url RLIKE '^(www\\.)?".$src_url."$' AND status = 'show' OR
													url RLIKE '^(www\\.)?".$src_url."$' AND status = 'black'";

			$result = $dbh->query($query);

			if(!$result) throw new ExceptionMySQL($dbh->error,"Error executing SQL query!");
			
			if($result->num_rows > 0){
				$error[] = MSG_ERROR_ERRORALREADY_EXISTS;
			}

			$result->close();

			$query = "SELECT * FROM ".DB_LINKS." WHERE url RLIKE '^(www\\.)?".$src_url."$' AND status = 'new' OR
												url RLIKE '^(www\\.)?".$src_url."$' AND status = 'hide'";

			$result = $dbh->query($query);

			if(!$result) throw new ExceptionMySQL($dbh->error,$query,"Error executing SQL query!");
			
			if($result->num_rows > 0){
				$error[] = MSG_ERROR_WAIT_VERIFICATION;
			}

			$result->close();
		}

		// Check category is chosen, if not then print error
		if($_POST["id_cat"] == 0){
			$error[] = MSG_ERROR_CHOOSE_CATEGORY;
		}

		// Check the url on valid
		if(!empty($_POST["url"]) and check_url($_POST["url"])){
			$error[] = MSG_ERROR_WRONG_URL;			
		}

		// Check on, whether the adding site on the same hosting as catalogue is located
		if((!empty($_POST["url"]) and $settings['common_host'] == "yes") and common_host ($_POST["url"]))
		{
			$error[] = MSG_ERROR_SAME_HOSTING;			
		}

		// Check email on valid
		if(!empty($_POST["email"]) and check_email($_POST["email"])){
			$error[] = MSG_ERROR_WRONG_EMAIL;
		}

		// Check brief description of site on spaces
		if(!empty($_POST["description"]) and len_description($_POST["description"])){
			$error[] = MSG_ERROR_SHORT_DESC_WITHOUT_SPACES;
		}

		// Check full description of site on a quantity of characters
		if(!empty($_POST["full_description"]) and len_description($_POST["full_description"])){
			$error[] = MSG_ERROR_FULL_DESC_WITHOUT_SPACES;
		}

		// Check HTML code of banner on valid
		if(!empty($_POST["htmlcode_banner"])){
			// check htmlcode of banner
			if(check_htmlcode_banner($_POST["htmlcode_banner"])){
				$error[] = MSG_ERROR_WRONG_HTML_BANNER;
			}
			else{
				// check image size of banner
				if(check_size_banner($_POST["htmlcode_banner"])){
					$error[] = MSG_ERROR_SIZE_BANNER;
				}

				// check image type of banner
				if(check_type_image_banner($_POST["htmlcode_banner"])){
					$error[] = MSG_ERROR_EXEND_BANNER;
				}
			}
		}

		// Check all required fields is filled
		// Check site name, if its value is empty print error
		if(empty($_POST["name"])){
			$error[] = MSG_ERROR_NOFILL_NAME;
		}

		// Check site address, if its value is empty print error
		if(empty($_POST["url"])){
			$error[] = MSG_ERROR_NOFILL_URL;
		}

		// Check reciprocal link, if its value is empty print error
		if(empty($_POST["description"])){
			$error[] = MSG_ERROR_NOFILL_BRIEFDESC;
		}

		// Check email, if its value is empty print error
		if(empty($_POST["full_description"])){
			$error[] = MSG_ERROR_NOFILL_FULLDESC;
		}

		// Shield a special characters		
		$_POST["name"] = $dbh->real_escape_string($_POST["name"]);
		$_POST["email"] = $dbh->real_escape_string($_POST["email"]);
		$_POST["keywords"] = $dbh->real_escape_string($_POST["keywords"]);
		$_POST["url"]  = $dbh->real_escape_string($_POST["url"]);
		$_POST["reciprocal_link"] = $dbh->real_escape_string($_POST["reciprocal_link"]);
		$_POST["description"] = $dbh->real_escape_string($_POST["description"]);
		$_POST["full_description"] = $dbh->real_escape_string($_POST["full_description"]);
		$_POST["htmlcode_banner"] = $dbh->real_escape_string($_POST["htmlcode_banner"]);
		$_POST["id_cat"] = $dbh->real_escape_string($_POST["id_cat"]);		

		// Add the link if not any errors
		if(count($error) == 0){
			$token = getRandomCode();

			// Form the SQL query on the adding of link
			$insert = "INSERT INTO ".DB_LINKS." (`id_link`,`name`,`url`,`reciprocal_link`,`time`,`email`,`keywords`,`description`,`full_description`,`htmlcode_banner`,`id_cat`,`status`,`token`,`check_link`,`reason`)
						VALUES (0,
								'".$_POST['name']."',
								'".$_POST['url']."',
								'".$_POST['reciprocal_link']."',
								now(),
								'".$_POST['email']."',
								'".$_POST['keywords']."',
								'".$_POST['description']."',
								'".$_POST['full_description']."',
								'".$_POST['htmlcode_banner']."',
								'".$_POST['id_cat']."',
								'show',
								'".$token."',
								'".$check_link."',
								'');";
								
			$result = $dbh->query($insert);
			if(!$result) throw new ExceptionMySQL($dbh->error,$insert,"Error executing SQL query!");
			
			// Return to the main page if a SQL query is executed successfully
			unset($_POST);
			$success = MSG_LINK_ADDED;
		}
	}
	
	$check_link = $_POST['check_link'] == 'on' ? 'yes':'no';
	
	// include temlate
	$tpl = SeparateTemplate::instance()->loadSourceFromFile("templates/addlink.tpl");
		
	//header
	include "header.inc";		
	
	//
	$tpl->assign('TITLE', TITLE_ADD_NEW_LINK);
	$tpl->assign('TITLEPAGE', TITLEADMIN_PAGE_ADD_NEW_LINK);	
	$tpl->assign('HELP', INFO_ADD_NEW_LINK);	
	
	if($success) $tpl->assign('MSG_ALERT', $success);	
		
	// menu
	include "menu.inc";		
			
	//form
	$tpl->assign('STR_REQUIRED_FIELDS', STR_REQUIRED_FIELDS);
	$tpl->assign('STR_CATEGORY', STR_CATEGORY);
	$tpl->assign('STR_CHOOSE_CATEGORY', STR_CHOOSE_CATEGORY);
	$tpl->assign('STR_WEBSITE_NAME', STR_WEBSITE_NAME);	
	$tpl->assign('STR_URL', STR_URL);
	$tpl->assign('STR_ADDRESS_OF_RECIP_LINK_PAGE', STR_ADDRESS_OF_RECIP_LINK_PAGE);
	$tpl->assign('STR_EMAIL', STR_EMAIL);
	$tpl->assign('STR_ONLY_TEXT_NOT_HTML', STR_ONLY_TEXT_NOT_HTML);
	$tpl->assign('STR_KEYWORDS', STR_KEYWORDS);
	$tpl->assign('STR_LIST_SEPARATED_BY_COMMAS', STR_LIST_SEPARATED_BY_COMMAS);
	$tpl->assign('STR_BRIEF_DESCRIPTION', STR_BRIEF_DESCRIPTION);
	$tpl->assign('STR_TO_CHECK_THIS_LINK', STR_TO_CHECK_THIS_LINK);
	$tpl->assign('STR_FULL_DESCRIPTION', STR_FULL_DESCRIPTION);
	$tpl->assign('STR_HTML_CODE_OF_BANNER', STR_HTML_CODE_OF_BANNER);
	$tpl->assign('BUTTON', BUTTON_ADD);
		
	//value		
	$tpl->assign('HIDDEN_FIELD','');
	$tpl->assign('ACTION', $_SERVER['PHP_SELF']);
	$tpl->assign('OPTION', ShowTree(0, 0));
	$tpl->assign('NAME', $_POST['name']);
	$tpl->assign('URL', $_POST['url']);
	$tpl->assign('RECIPROCAL_LINK', $_POST['reciprocal_link']);
	$tpl->assign('EMAIL', $_POST['email']);		
	$tpl->assign('KEYWORDS', $_POST['keywords']);		
	$tpl->assign('DESCRIPTION', $_POST['description']);
	$tpl->assign('FULL_DESCRIPTION', $_POST{'full_description'});
	$tpl->assign('FULL_DESCRIPTION', $_POST['htmlcode_banner']);
	$tpl->assign('ID_CAT', $_POST['id_cat']);
	$tpl->assign('CHECK_LINK', $check_link);	
	
	//show errors
	if(count($error) > 0){
		$errorBlock = $tpl->fetch('show_errors');
		$errorBlock->assign('STR_IDENTIFIED_FOLLOWING_ERRORS', STR_IDENTIFIED_FOLLOWING_ERRORS);
		$errorBlock->assign('MSG_ERROR_ERRORALREADY_EXISTS', MSG_ERROR_ERRORALREADY_EXISTS);
		$errorBlock->assign('MSG_ERROR_WAIT_VERIFICATION', MSG_ERROR_WAIT_VERIFICATION);
		$errorBlock->assign('MSG_ERROR_CHOOSE_CATEGORY', MSG_ERROR_CHOOSE_CATEGORY);
		$errorBlock->assign('MSG_ERROR_WRONG_URL', MSG_ERROR_WRONG_URL);
		$errorBlock->assign('MSG_ERROR_SAME_HOSTING', MSG_ERROR_SAME_HOSTING);
		$errorBlock->assign('MSG_ERROR_WRONG_EMAIL', MSG_ERROR_WRONG_EMAIL);
		$errorBlock->assign('MSG_ERROR_SHORT_DESC_WITHOUT_SPACES', MSG_ERROR_SHORT_DESC_WITHOUT_SPACES);
		$errorBlock->assign('MSG_ERROR_FULL_DESC_WITHOUT_SPACES', MSG_ERROR_FULL_DESC_WITHOUT_SPACES);
		$errorBlock->assign('MSG_ERROR_WRONG_HTML_BANNER', MSG_ERROR_WRONG_HTML_BANNER);
		$errorBlock->assign('MSG_ERROR_SIZE_BANNER', MSG_ERROR_SIZE_BANNER);
		$errorBlock->assign('MSG_ERROR_EXEND_BANNER', MSG_ERROR_EXEND_BANNER);
		$errorBlock->assign('MSG_ERROR_NOFILL_NAME', MSG_ERROR_NOFILL_NAME);
		$errorBlock->assign('MSG_ERROR_NOFILL_URL', MSG_ERROR_NOFILL_URL);
		$errorBlock->assign('MSG_ERROR_NOFILL_BRIEFDESC', MSG_ERROR_NOFILL_BRIEFDESC);
		$errorBlock->assign('MSG_ERROR_NOFILL_FULLDESC', MSG_ERROR_NOFILL_FULLDESC);
			
		foreach($error as $row){
			$rowBlock = $errorBlock->fetch('row');
			$rowBlock->assign('ERROR', $row);
			$errorBlock->assign('row', $rowBlock);
		}
		
		$tpl->assign('show_errors', $errorBlock);
	}
			
	//footer
	include "footer.inc";
		
	// Count a quantity of the links
	$query = "SELECT COUNT(*) FROM ".DB_LINKS." WHERE status = 'show'";
	$result = $dbh->query($query);
		
	if(!$result) throw new ExceptionMySQL($dbh->error,$query,"Error executing SQL query!");
		
	$total = $result->fetch_assoc();

	// Clear the descriptor
	$result->close();
		
	$tpl->assign("TOTAL_LINKS", $total['COUNT(*)']);
	$tpl->assign("STR_HELP", STR_HELP);
		
	// print html page
	$tpl->display();

	$dbh->close();
}
catch(ExceptionMySQL $exc)
{
	require_once("../lib/exception_mysql_debug.inc");
}

?>
